<?php
if (!defined('ABSPATH')) exit;

// Admin page for adding questions
function snmcqs_quiz_admin_page() {
    global $wpdb;
    $questions_table = $wpdb->prefix . SNMCQS_PREFIX . 'questions';
    $message = ''; // Variable to store success message

    if (
        isset($_SERVER['REQUEST_METHOD'])
        && $_SERVER['REQUEST_METHOD'] == 'POST'
        && isset($_POST['snmcqs_question'])
    ) {
        // Verify nonce before allowing admins to create a question
        check_admin_referer('snmcqs_form_action', 'snmcqs_nonce');

        // Sanitize input and remove slashes
        $question = isset($_POST['snmcqs_question']) ? sanitize_text_field(wp_unslash($_POST['snmcqs_question'])) : '';
        $options = isset($_POST['snmcqs_options']) ? array_map('sanitize_text_field', wp_unslash($_POST['snmcqs_options'])): null;

        // Always set correct_option to 0
        $correct_option = 0;

        // Insert data into the database
        $inserted = $wpdb->insert( // phpcs:ignore WordPress.DB.DirectDatabaseQuery
            $questions_table,
            [
                'question'       => $question,
                'options'        => maybe_serialize($options),
                'correct_option' => $correct_option,
            ],
            ['%s', '%s', '%d']
        );

        // default error message is error notice, until we confirm that question was inserted successfully
        $message = '<div class="updated notice error"><p>Failed to add question, try again!</p></div>';

        // Show success message if insert was successful
        if ($inserted) {
            $message = '<div class="updated notice"><p>Question added successfully! <a href="?page=snmcqs-quiz-existingques">View Existing Questions</a></p></div>';
        }
    }
    ?>

    <div class="snmcqs-container">
        <h1>Quiz Questions</h1>
        
        <?php if (!empty($message)) echo wp_kses_post($message); ?>

        <form method="post" class="snmcqs-form">
            <?php wp_nonce_field('snmcqs_form_action', 'snmcqs_nonce'); ?>

            <label>Question:</label>
            <input type="text" name="snmcqs_question" required>

            <label>Options:</label>
            <input type="text" name="snmcqs_options[]" placeholder="Option 1" required>
            <input type="text" name="snmcqs_options[]" placeholder="Option 2" required>
            <input type="text" name="snmcqs_options[]" placeholder="Option 3" required>
            <input type="text" name="snmcqs_options[]" placeholder="Option 4" required>

            <input type="submit" value="Add Question">
        </form>
    </div>

    <?php
}


// page to display existing questions to user
function snmcqs_admin_existingques_page() {
    global $wpdb;
    $questions_table = $wpdb->prefix . SNMCQS_PREFIX . 'questions';

    // it is ok to use direct db query because we are fetching data from custom table
    $questions = $wpdb->get_results("SELECT * FROM " . esc_sql($questions_table)); // phpcs:ignore WordPress.DB.DirectDatabaseQuery
    ?>
    <div class="wrap">
        <h2 class="snmcqs-questions-heading">Existing Questions</h2>
        <table class="snmcqs-wp-list-table widefat fixed striped">
            <thead>
                <tr>
                    <th>Question</th>
                    <th>ID</th>
                    <th>Shortcode</th>
                    <th>Results</th>
                </tr>
            </thead>
            <tbody>
            <?php
            $nonce = wp_create_nonce('view_results_nonce');

            // loop through each question and display it in table
            foreach ($questions as $q) {
                echo "<tr>";
                echo "<td>". esc_html($q->id)."</td>";
                echo "<td>". esc_html($q->question )."</td>";
                echo "<td>[snmcqs_quiz id=". esc_html($q->id )."]</td>";
                echo "<td><a href='?page=snmcqs-quiz-user-responses&question_id=" . esc_attr($q->id) . "&_wpnonce=" . esc_attr($nonce) . "'>View Results</a></td>";
                echo "</tr>";
            } ?>
            </tbody>
        </table>
    </div>
    <?php
}

// display user's responses to queestions
function snmcqs_display_responses() {
    global $wpdb;

    // verify nonce before displaying results
    check_admin_referer('view_results_nonce');

    // make sure that question_id is passed in query string, otherwise set default to 0
    $question_id = isset($_GET['question_id']) ? intval($_GET['question_id']) : 0;

    if (!$question_id) {
        echo "<p style='color: red;'>Error: No question ID provided.</p>";
        return;
    }

    $questions_table = $wpdb->prefix . SNMCQS_PREFIX . 'questions';
    $responses_table = $wpdb->prefix . SNMCQS_PREFIX . 'responses';

    $question = $wpdb->get_row($wpdb->prepare( // phpcs:ignore WordPress.DB.DirectDatabaseQuery
        "SELECT * FROM " . esc_sql($questions_table) . " WHERE id = %d",
        $question_id
    ));

    if (!$question) {
        echo "<p style='color: red;'>Error: Question not found.</p>";
        return;
    }

    $options = maybe_unserialize($question->options);
    $response_counts = $wpdb->get_results($wpdb->prepare( // phpcs:ignore WordPress.DB.DirectDatabaseQuery
        "SELECT selected_option, COUNT(*) as count FROM " . esc_sql($responses_table) . " WHERE question_id = %d GROUP BY selected_option",
        $question_id
    ), OBJECT_K);

    $chart_labels = [];
    $chart_data = [];

    foreach ($options as $index => $option) {
        $count = isset($response_counts[$index]) ? $response_counts[$index]->count : 0;
        $chart_labels[] = $option;
        $chart_data[] = $count;
    }
    ?>

    <div class="snmcqs-chart-container">
        <h2><?php echo esc_html($question->question); ?></h2>
        <canvas id="surveyChart"
                data-labels='<?php echo esc_html(wp_json_encode($chart_labels)); ?>'
                data-data='<?php echo esc_html(wp_json_encode($chart_data)); ?>'>
        </canvas>
    </div>
    <?php
}
