<?php
if (!defined('ABSPATH')) exit;

// Handle user submissions via AJAX
function snmcqs_quiz_submit() {
    global $wpdb;
    $questions_table = $wpdb->prefix . SNMCQS_PREFIX . 'questions';
    $responses_table = $wpdb->prefix . SNMCQS_PREFIX . 'responses';

    // Get the user ID (if logged in, otherwise set to 0 for guests)
    $user_id = get_current_user_id() ?: 0;

    // check nonce before processing post data
    if (
        !isset($_POST['snmcqs_nonce']) || 
        !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['snmcqs_nonce'])), 'snmcqs_form_action')
    ) {
        echo "Security check failed.";
        wp_die();
    }
    
    

    // Debug: Check if data is being received correctly
    if (empty($_POST)) {
        echo "Error: No data received.";
        wp_die();
    }

    $success_count = 0;
    
    // user didn't answer
    if (!isset($_POST['questions']) || !is_array($_POST['questions'])) {
        wp_send_json_error(['message' => 'No questions submitted.']);
        wp_die();
    }
    
    // Loop through received answers
    foreach ($_POST['questions'] as $key => $value) {
        // Extract question ID from "question_123"
        $question_id = intval(str_replace('question_', '', sanitize_text_field($key)));
        $selected_option = intval($value);

        // Ensure the question exists
        // it is ok to use direct inserts because we are fetching data from custom table
        $question = $wpdb->get_row( // phpcs:ignore WordPress.DB.DirectDatabaseQuery
            $wpdb->prepare("SELECT id FROM ". esc_sql($questions_table) ." WHERE id = %d", $question_id)
        );
        if (!$question) continue;

        // Insert user response
        // it is ok to use direct inserts because we are inserting data from custom table
        $wpdb->insert($responses_table, [ // phpcs:ignore WordPress.DB.DirectDatabaseQuery
            'question_id' => $question_id,
            'user_id' => $user_id,
            'selected_option' => $selected_option
        ]);  //db call ok

        if ($wpdb->insert_id) {
            $success_count++;
        }
    }

    // Response message
    if ($success_count > 0) {
        echo "Your answers have been successfully submitted!";
    } else {
        echo "Error: Answers could not be saved.";
    }

    wp_die();
}

add_action('wp_ajax_snmcqs_quiz_submit', 'snmcqs_quiz_submit');
add_action('wp_ajax_nopriv_snmcqs_quiz_submit', 'snmcqs_quiz_submit');
