<?php
if (!defined('ABSPATH')) exit;

// Shortcode to display questions
function snmcqs_quiz_shortcode($atts) {
    global $wpdb;
    $questions_table = $wpdb->prefix . SNMCQS_PREFIX . 'questions';

    // Extract shortcode attributes
    $atts = shortcode_atts(['id' => ''], $atts);
    $question_ids = $atts['id'];
 
    // admin wants to display specific questions to the user
    if (!empty($question_ids)) {
        $ids_array = array_map('intval', explode(',', $question_ids));
 
        // loop through each question id and get questions
        foreach ($ids_array as $ques_id) {
            // it is ok to use direct query because we are fetching data from custom table
            $row = $wpdb->get_row($wpdb->prepare( // phpcs:ignore WordPress.DB.DirectDatabaseQuery
                 "SELECT * FROM ". esc_sql($questions_table) ." WHERE id = %d", $ques_id)
            );

            // only store question to questions array if question exists for id
            if ($row) {
                $questions[] = $row;
            }
        }
    }  else {
        // Get all questions if no ID is specified
        // it is ok to use direct query because we are fetching data from custom table
        $questions = $wpdb->get_results("SELECT * FROM " . esc_sql($questions_table)); // phpcs:ignore WordPress.DB.DirectDatabaseQuery
    }

    if (!$questions) {
        return "<p>No questions available.</p>";
    }

    ob_start();
    ?>
    <form id="snmcqs-quiz-form">
        <input type="hidden" name="snmcqs_nonce" value="<?php echo esc_attr(wp_create_nonce('snmcqs_form_action')); ?>">
        <?php foreach ($questions as $q) {
            $options = maybe_unserialize($q->options);
            echo "<p><b>". esc_html($q->question)."</b></p>";
            foreach ($options as $index => $option) {
                echo "<label><input type='radio' name='questions[". esc_html($q->id) ."]' value='". esc_html($index) ."'> ". esc_html($option) ."</label><br>";
            }
        } ?>
        <input type="hidden" name="snmcqs_quiz_action" value="submit">
        <input type="submit" value="Submit">
    </form>
    <div id="snmcqs-response"></div>
    <?php
    return ob_get_clean();
}

add_shortcode('snmcqs_quiz', 'snmcqs_quiz_shortcode');
